Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1446)

Unified Diff: chrome/common/autofill_messages.h

Issue 11821020: Chrome-side implementation of AutocompleteErrorEvent#reason. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/autofill_messages.h
diff --git a/chrome/common/autofill_messages.h b/chrome/common/autofill_messages.h
index ec032bf9ca4e25118b6ae454df2078a596c3cab2..4501aa1eb8b43c8037d473d4a8d6249785ee1b6f 100644
--- a/chrome/common/autofill_messages.h
+++ b/chrome/common/autofill_messages.h
@@ -137,17 +137,13 @@ IPC_MESSAGE_ROUTED1(AutofillMsg_AcceptPasswordAutofillSuggestion,
IPC_MESSAGE_ROUTED1(AutofillMsg_FormNotBlacklisted,
content::PasswordForm /* form checked */)
-// Sent when requestAutocomplete() succeeds. Tells the renderer to Autofill the
-// form that requested autocomplete with the |form_data| values input by the
-// user.
-IPC_MESSAGE_ROUTED1(AutofillMsg_RequestAutocompleteSuccess,
+// Sent when requestAutocomplete() finishes (either succesfully or with an
+// error). If it was a success, the renderer fills the form that requested
+// autocomplete with the |form_data| values input by the user.
+IPC_MESSAGE_ROUTED2(AutofillMsg_RequestAutocompleteResult,
+ WebKit::WebFormElement::AutocompleteResult /* result */,
FormData /* form_data */)
-// Sent when requestAutocomplete() fails. Currently, this happens when a form is
-// requested to be autocompleted with no input or select tags with autocomplete
-// attributes.
-IPC_MESSAGE_ROUTED0(AutofillMsg_RequestAutocompleteError)
-
// Autofill messages sent from the renderer to the browser.
// TODO(creis): check in the browser that the renderer actually has permission

Powered by Google App Engine
This is Rietveld 408576698